Index: /issm/trunk/src/m/solutions/macayeal/diagnostic.m
===================================================================
--- /issm/trunk/src/m/solutions/macayeal/diagnostic.m	(revision 1957)
+++ /issm/trunk/src/m/solutions/macayeal/diagnostic.m	(revision 1958)
@@ -7,4 +7,10 @@
 %   Usage:
 %      md=diagnostic(md)
+
+%control method?
+if md.control_analysis==1,
+	md=control(md);
+	return;
+end
 
 %First check we do have the correct argument number
Index: /issm/trunk/src/m/utils/Nightly/testsgetfields.m
===================================================================
--- /issm/trunk/src/m/utils/Nightly/testsgetfields.m	(revision 1957)
+++ /issm/trunk/src/m/utils/Nightly/testsgetfields.m	(revision 1958)
@@ -1,10 +1,10 @@
-function fields=testsgetfields(mdtype,string),
-%TESTSGETfields - build the fields to be checked from a string
+function fields=testsgetfields(mdtype,analysis),
+%TESTSGETFIELDS - build the fields to be checked from a analysis
 %
 %   This routine is used by nightly runs (runme.m and updatearchive.m).
 %   for an input string 'prognostic', it will output 'cielo'
 %
 %   Usage:
-%      fields=testsgetfields(mdtype,string)
+%      fields=testsgetfields(mdtype,analysis)
 %
 %   Example:
@@ -13,5 +13,5 @@
 %   See also: TESTSGETANALYSIS, TESTGETPACKAGE
 
-if strcmpi(string,'diagnostic'),
+if strcmpi(analysis,'diagnostic'),
 	if strcmpi(mdtype,'3d')
 		fields={'diagnostic.vy','diagnostic.vz'};
@@ -20,14 +20,14 @@
 	end
 
-elseif strcmpi(string,'thermal_steady'),
+elseif strcmpi(analysis,'thermal_steady'),
 	fields={'thermal.temperature','thermal.melting'};
 
-elseif strcmpi(string,'thermal_transient'),
+elseif strcmpi(analysis,'thermal_transient'),
 	fields={'thermal(end).temperature','thermal(end).melting'};
 
-elseif strcmpi(string,'prognostic'),
+elseif strcmpi(analysis,'prognostic'),
 	fields={'prognostic.thickness'};
 
-elseif strcmpi(string,'transient'), 
+elseif strcmpi(analysis,'transient'), 
 	if strcmpi(mdtype,'3d')
 		fields={'transient(end).vel','transient(end).pressure','transient(end).temperature','transient(end).melting','transient(end).thickness','transient(end).surface','transient(end).bed'};
@@ -36,11 +36,14 @@
 	end
 
-elseif strcmpi(string,'steadystate'), 
+elseif strcmpi(analysis,'steadystate'), 
 	fields={'steadystate.vel','steadystate.pressure','steadystate.temperature'};
 
-elseif strcmpi(string,'control'),
-	fields={'control.vel','control.J','control.parameter'};
+elseif strncmpi(analysis,'diagnostic_',11),
+	fields={'diagnostic.vel','diagnostic.J','diagnostic.parameter'};
+
+elseif strncmpi(analysis,'steadystate_',12),
+	fields={'steadystate.vel','steadystate.J','steadystate.parameter'};
 
 else
-	error(['testsgetfields error message: solution '  string ' not supported yet']);
+	error(['testsgetfields error message: solution '  analysis ' not supported yet']);
 end
@@ -1,10 +1,10 @@
 %
 %   This routine is used by nightly runs (runme.m and updatearchive.m).
-%   for an input string 'prognostic', it will output 'cielo'
+%   for an input analysis 'prognostic', it will output 'cielo'
 %
 %   Usage:
